@@ -71,7 +71,7 @@ function _config_manila_apache_wsgi {
     sudo sed -e "
         s|%APACHE_NAME%|$APACHE_NAME|g;
         s|%MANILA_BIN_DIR%|$MANILA_BIN_DIR|g;
-        s|%PORT%|$REAL_MANILA_SERVICE_PORT|g;
+        s|%PORT%|$MANILA_SERVICE_PORT|g;
         s|%APIWORKERS%|$API_WORKERS|g;
         s|%USER%|$STACK_USER|g;
     " -i $manila_api_apache_conf
@@ -204,13 +204,8 @@ function configure_manila {
     iniset $MANILA_CONF DEFAULT rootwrap_config $MANILA_CONF_DIR/rootwrap.conf
     iniset $MANILA_CONF DEFAULT osapi_share_extension manila.api.contrib.standard_extensions
     iniset $MANILA_CONF DEFAULT state_path $MANILA_STATE_PATH
-
-    # Note: Sample share types will still be created if the below is False
-
-    if [ $(trueorfalse False MANILA_CONFIGURE_DEFAULT_TYPES) == True ]; then
-        iniset $MANILA_CONF DEFAULT default_share_type $MANILA_DEFAULT_SHARE_TYPE
-        iniset $MANILA_CONF DEFAULT default_share_group_type $MANILA_DEFAULT_SHARE_GROUP_TYPE
-    fi
+    iniset $MANILA_CONF DEFAULT default_share_type $MANILA_DEFAULT_SHARE_TYPE
+    iniset $MANILA_CONF DEFAULT default_share_group_type $MANILA_DEFAULT_SHARE_GROUP_TYPE
 
     if ! [[ -z $MANILA_SHARE_MIGRATION_PERIOD_TASK_INTERVAL ]]; then
         iniset $MANILA_CONF DEFAULT migration_driver_continue_update_interval $MANILA_SHARE_MIGRATION_PERIOD_TASK_INTERVAL
@@ -260,14 +255,9 @@ function configure_manila {
 
     iniset $MANILA_CONF DEFAULT manila_service_keypair_name $MANILA_SERVICE_KEYPAIR_NAME
 
-    REAL_MANILA_SERVICE_PORT=$MANILA_SERVICE_PORT
     if is_service_enabled tls-proxy; then
-        # Set the protocol to 'https', and set the default port
-        MANILA_SERVICE_PROTOCOL="https"
-        REAL_MANILA_SERVICE_PORT=$MANILA_SERVICE_PORT_INT
         # Set the service port for a proxy to take the original
-        iniset $MANILA_CONF DEFAULT osapi_share_listen_port $REAL_MANILA_SERVICE_PORT
-        iniset $MANILA_CONF oslo_middleware enable_proxy_headers_parsing True
+        iniset $MANILA_CONF DEFAULT osapi_share_listen_port $MANILA_SERVICE_PORT_INT
     fi
 
     iniset_rpc_backend manila $MANILA_CONF DEFAULT
@@ -332,7 +322,13 @@ function create_service_share_servers {
                 fi
 
                 floating_ip=$(openstack floating ip create $PUBLIC_NETWORK_NAME --subnet $PUBLIC_SUBNET_NAME | grep 'floating_ip_address' | get_field 2)
-                openstack server add floating ip $vm_id $floating_ip
+                # TODO(rishabh-d-dave): For time being circumvent the bug -
+                # https://bugs.launchpad.net/python-openstackclient/+bug/1747721
+                # Once fixed, replace the following 3 lines by -
+                # openstack server add floating ip $vm_id $floating_ip
+                vm_port_id=$(openstack port list --server $vm_id -c ID -f \
+                    value)
+                openstack floating ip set --port $vm_port_id $floating_ip
 
                 iniset $MANILA_CONF $BE service_instance_name_or_id $vm_id
                 iniset $MANILA_CONF $BE service_net_name_or_ip $floating_ip
@@ -485,11 +481,13 @@ function create_default_share_group_type {
     fi
 }
 
-# create_default_share_type - create share type that will be set as default
-# if $MANILA_CONFIGURE_DEFAULT_TYPES is set to True, if set to False, the share
-# type identified by $MANILA_DEFAULT_SHARE_TYPE is still created, but not
-# configured as default.
+# create_default_share_type - create share type that will be set as default.
 function create_default_share_type {
+    echo "Waiting for Manila API to start..."
+    if ! wait_for_service 60 $MANILA_SERVICE_PROTOCOL://$MANILA_SERVICE_HOST:$MANILA_SERVICE_PORT; then
+        die $LINENO "Manila did not start"
+    fi
+
     enabled_backends=(${MANILA_ENABLED_BACKENDS//,/ })
     driver_handles_share_servers=$(iniget $MANILA_CONF ${enabled_backends[0]} driver_handles_share_servers)
 
@@ -800,20 +798,14 @@ function start_manila_api {
         run_process m-api "$MANILA_BIN_DIR/manila-api --config-file $MANILA_CONF"
     fi
 
-
     echo "Waiting for Manila API to start..."
-    # This is a health check against the manila-api service we just started.
-    # We use the port ($REAL_MANILA_SERVICE_PORT) here because we want to hit
-    # the bare service endpoint, even if the tls tunnel should be enabled.
-    # We're making sure that the internal port is checked using unencryted
-    # traffic at this point.
-    if ! wait_for_service $SERVICE_TIMEOUT $MANILA_SERVICE_PROTOCOL://$MANILA_SERVICE_HOST:$REAL_MANILA_SERVICE_PORT; then
+    if ! wait_for_service $SERVICE_TIMEOUT $MANILA_SERVICE_PROTOCOL://$MANILA_SERVICE_HOST:$MANILA_SERVICE_PORT; then
         die $LINENO "Manila API did not start"
     fi
 
     # Start proxies if enabled
     if is_service_enabled tls-proxy; then
-        start_tls_proxy manila '*' $MANILA_SERVICE_PORT $MANILA_SERVICE_HOST $MANILA_SERVICE_PORT_INT
+        start_tls_proxy '*' $MANILA_SERVICE_PORT $MANILA_SERVICE_HOST $MANILA_SERVICE_PORT_INT &
     fi
 }
 
